@@ -146,7 +146,9 @@ async def reduce(
                 initial if initial is not __REDUCE_SENTINEL else await anext(item_iter)
             )
         except StopAsyncIteration:
-            raise TypeError("reduce() of empty sequence with no initial value")
+            raise TypeError(
+                "reduce() of empty sequence with no initial value"
+            ) from None
         function = _awaitify(function)
         async for head in item_iter:
             value = await function(value, head)
